@@ -5,7 +5,7 @@
 #' This is a S3 generic, specialized for at least the following objects:
 #'
 #' 1. [TaskClassif]: ensure the identity
-#' 2. [data.frame()] and [DataBackend]: provides an alternative to the constructor of [TaskClassif].
+#' 2. [`formula`], [data.frame()] and [DataBackend]: provides an alternative to the constructor of [TaskClassif].
 #' 3. [TaskRegr]: Calls [convert_task()].
 #'
 #' @inheritParams as_task
@@ -30,12 +30,12 @@ as_task_classif.TaskClassif = function(x, clone = FALSE, ...) { # nolint
 #' @template param_target
 #' @param id (`character(1)`)\cr
 #'   Id for the new task.
-#'   Defaults to the (deparsed and substituted) name of `x`.
+#'   Defaults to the (deparsed and substituted) name of the data argument.
 #' @param positive (`character(1)`)\cr
 #'   Level of the positive class. See [TaskClassif].
 #' @export
 as_task_classif.data.frame = function(x, target = NULL, id = deparse(substitute(x)), positive = NULL, ...) { # nolint
-  ii = which(map_lgl(subset(x, select = map_lgl(x, is.double)), anyInfinite))
+  ii = which(map_lgl(keep(x, is.double), anyInfinite))
   if (length(ii)) {
     warningf("Detected columns with unsupported Inf values in data: %s", str_collapse(names(ii)))
   }
@@ -56,3 +56,19 @@ as_task_classif.DataBackend = function(x, target = NULL, id = deparse(substitute
 as_task_classif.TaskRegr = function(x, target = NULL, drop_original_target = FALSE, drop_levels = TRUE, ...) { # nolint
   convert_task(intask = x, target = target, new_type = "classif", drop_original_target = FALSE, drop_levels = TRUE)
 }
+
+#' @rdname as_task_classif
+#' @param data (`data.frame()`)\cr
+#'   Data frame containing all columns specified in formula `x`.
+#' @export
+as_task_classif.formula = function(x, data, id = deparse(substitute(data)), positive = NULL, ...) { # nolint
+  assert_data_frame(data)
+  assert_subset(all.vars(x), c(names(data), "."), .var.name = "formula")
+  if (!attributes(terms(x, data = data))$response) {
+    stopf("Formula %s is missing a response", format(x))
+  }
+  tab = model.frame(x, data)
+  target = all.vars(x)[1L]
+
+  as_task_classif(tab, target = target, id = id, positive = positive, ...)
+}
